@@ -17,10 +17,12 @@ class ModelField(object):
             Field cannot be null
         """
 
-    def __init__(self, required=True, blank=False, null=True, default=None, **kwargs):
+    def __init__(self, verbose_name='', help_text='', required=True, blank=False, null=True, default=None, **kwargs):
         """
         """
 
+        self.verbose_name = verbose_name
+        self.help_text = help_text
         self.required = required
         self.blank = blank
         self.null = null
@@ -558,7 +560,10 @@ class ForeignKeyField(ModelField):
         """
         """
 
-        return u'%s' % self.relation_model.document
+        if self.relation_model:
+            return u'%s' % self.relation_model.document
+        else:
+            return None
 
     def loads(self, model_id):
         """
